@@ -1,31 +1,28 @@
 /* Return the next element of a path.
    Copyright (C) 1992,2005 Free Software Foundation, Inc.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-   USA.
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* Written by David MacKenzie <djm@gnu.org>,
    inspired by John P. Rouillard <rouilj@cs.umb.edu>.  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
+
 
 #include <stdio.h>
-#if defined(HAVE_STRING_H) || defined(STDC_HEADERS)
+#if defined HAVE_STRING_H || defined STDC_HEADERS
 #include <string.h>
 #else
 #include <strings.h>
@@ -33,7 +30,7 @@
 #define strchr index
 #endif
 #endif
-#if defined(STDC_HEADERS)
+#if defined STDC_HEADERS
 #include <stdlib.h>
 #endif
 
